{% import 'bootstrapform/field_macros.jinja' as field_macros %}

{%- if form.non_field_errors() %}
  <div class="alert alert-danger">
    <a class="close" data-dismiss="alert">&times;</a>
    {% for non_field_error in form.non_field_errors() %}
      {{ non_field_error }}
    {% endfor %}
  </div>
{% endif -%}

{%- for field in form.hidden_fields() %}
  {{ field|safe }}
{% endfor -%}

{%- for field in form.visible_fields() %}
  {{ field_macros.render(form, field, classes) }}
{% endfor %}
