{{ formset.management_form }}

{% for form in formset %}
  {% if classes.label == 'sr-only' %}
    <div class="form-inline">
  {% endif %}
      {% include 'bootstrapform/form.jinja' %}
  {% if classes.label == 'sr-only' %}
    </div>
  {% endif %}
{% endfor %}
